.. _users-news:

===========
In the News
===========

Media coverage
==============

* `"Building the Bionic Eye...With Car Tech?" <https://www.pcmag.com/news/building-the-bionic-eyewith-car-tech>`_, PCMag, Feb 2021.

* `"Restoring vision with bionic eyes: No longer science fiction" <https://www.pcmag.com/news/369401/restoring-vision-with-bionic-eyes-no-longer-science-fiction>`_, PCMag, July 2019.

Scholarly articles referencing pulse2percept
============================================
* A Xu, N Han, S Srivastava, D Klein, M Beyeler (2021). Enhancing simulated prosthetic vision with deep learning-based scene simplification strategies. *Journal of Vision*, doi:`10.1167/jov.21.9.2308 <https://doi.org/10.1167/jov.21.9.2308>`_.

* J Wang, H Zhu, J Liu, H Li, Y Han, R Zhou, Y Zhang (2021). The application of computer vision to visual prosthesis. *Artificial Organs*, doi:`10.1111/aor.14022 <https://doi.org/10.1111/aor.14022>`_.

* RB Esquenazi, K Meier, M Beyeler, GM Boynton, I Fine (2021). Learning to see again: Perceptual learning of simulated abnormal on- off-cell population responses in sighted individuals. *Journal of Vision*, doi:`10.1167/jov.21.13.10 <https://doi.org/10.1167/jov.21.13.10>`_.

* L Wang, N Marek, J Steffen, S Pollmann (2021). Perceptual Learning of Object Recognition in Simulated Retinal Implant Perception - The Effect of Video Training. *Translational Vision Science & Technology*, doi:`10.1167/tvst.10.12.22 <https://doi.org/10.1167/tvst.10.12.22>`_.

* A Benetatos, N Melanitis, KS Nikita (2021). Assessing Vision Quality in Retinal Prosthesis Implantees through Deep Learning: Current Progress and Improvements by Optimizing Hardware Design Parameters and Rehabilitation. *Annual International Conference of the IEEE Engineering in Medicine and Biology Society. IEEE Engineering in Medicine and Biology Society. Annual International Conference*, doi:`10.1109/EMBC46164.2021.9630963 <https://doi.org/10.1109/EMBC46164.2021.9630963>`_.

* N Han, S Srivastava, A Xu, D Klein, M Beyeler (2021). Deep Learning--Based Scene Simplification for Bionic Vision. *arXiv preprint*, arXiv:`2102.00297 <https://arxiv.org/abs/2102.00297>`_.

* D Haji Ghaffari (2021). Improving the Resolution of Prosthetic Vision through Stimulus Parameter Optimization. *Dissertations and Theses (Ph.D. and Master's), University of Michigan*. doi:`10.7302/3015 <https://dx.doi.org/10.7302/3015>`_

* T Fauvel, M Chalk (2021). Human-in-the-loop optimization of visual prosthetic stimulation. *bioRxiv* doi:`10.1101/2021.11.24.469867 <https://doi.org/10.1101/2021.11.24.469867>`_.

* A Lozano, JS Suarez, C Soto-Sanchez, J Garrigos, JJ Martinez-Alvarez, JM Ferrandez, E Fernandez (2020). Neurolight: A Deep Learning Neural Interface for Cortical Visual Prostheses. *International Journal of Neural Systems*, doi:`10.1142/S0129065720500458 <https://doi.org/10.1142/S0129065720500458>`_.

* C Erickson-Davis, H Korzybska (2020). What do blind people "see" with retinal prostheses? Observations and qualitative reports of epiretinal implant users. *bioRxiv*, doi:`10.1101/2020.02.03.932905 <https://doi.org/10.1101/2020.02.03.932905>`_.

* E Migliorini (2019). A real-time, GPU-based VR solution for simulating the POLYRETINA retinal neuroprosthesis. *Politecnico di Milano* `hdl.handle.net/10589/149850 <https://dx.doi.org/10.7302/3015>`_.

* M Beyeler, GM Boynton, I Fine, A Rokem (2019). Model-Based Recommendations for Optimal Surgical Placement of Epiretinal Implants. *Medical Image Computing and Computer Assisted Intervention - MICCAI 2019*, doi:`10.1007/978-3-030-32254-0_44 <https://doi.org/10.1007/978-3-030-32254-0_44>`_.

* J Steffen, G Hille, K Tonnies (2019). Automatic Perception Enhancement for Simulated Retinal Implants. *n Proceedings of the 8th International Conference on Pattern Recognition Applications and Methods (ICPRAM 2019)*, doi:`10.5220/0007695409080914 <https://doi.org/10.5220/0007695409080914>`_.

* BW Brunton, M Beyeler (2019). Data-driven models in human neuroscience and neuroengineering. *Current Opinion in Neurobiology* 58, 21-29, doi:`10.1016/j.conb.2019.06.008 <https://doi.org/10.1016/j.conb.2019.06.008>`_.

* A Lozano, JS Suarez, C Soto-Sanchez, J Garrigos, J-J Martinez, JM Ferrandez Vicente, E Fernandez-Jover (2019). Neurolight Alpha: Interfacing Computational Neural Models for Stimulus Modulation in Cortical Visual Neuroprostheses. *International Work-Conference on the Interplay Between Natural and Artificial Computation (IWINAC)*, doi:`10.1007/978-3-030-19591-5_12 <https://doi.org/10.1007/978-3-030-19591-5_12>`_.

* M Beyeler (2019). Biophysical model of axonal stimulation in epiretinal visual prostheses. *IEEE/EMBS Conference on Neural Engineering*, doi:`10.1109/NER.2019.8716969 <https://doi.org/10.1109/NER.2019.8716969>`_.

* NP Cottaris, H Jiang, X Ding, BA Wandell, DH Brainard (2019). A computational-observer model of spatial contrast sensitivity: Effects of wave-front-based optics, cone-mosaic structure, and inference engine. *Journal of Vision* 19(8), doi:`10.1167/19.4.8 <https://doi.org/10.1167/19.4.8>`_.

* M Beyeler, D Nanduri, JD Weiland, A Rokem, GM Boynton, I Fine (2019). A model of ganglion axon pathways accounts for percepts elicited by retinal implants. *Scientific Reports 9(1):9199*, doi:`10.1038/s41598-019-45416-4 <https://doi.org/10.1038/s41598-019-45416-4>`_.

* L Wang, F Sharifian, J Napp, C Nath, S Pollmann (2018). Cross-task perceptual learning of object recognition in simulated retinal implant perception. *Journal of Vision* 18(22), doi:`10.1167/18.13.22 <https://doi.org/10.1167/18.13.22>`_.

* J Huth, T Masquelier, A Arleo (2018). Convis: A toolbox to fit and simulate filter-based models of early visual processing. *Frontiers in Neuroinformatics*, doi:`10.3389/fninf.2018.00009 <https://doi.org/10.3389/fninf.2018.00009>`_.

* J Steffen, J Napp, S Pollmann, K Tönnies (2018). Perception Enhancement for Bionic Vision - Preliminary Study on Object Classification with Subretinal Implants. *Proceedings of the 7th International Conference on Pattern Recognition Applications and Methods, 169-177*. doi:`10.5220/0006648901690177 <https://doi.org/10.5220/0006648901690177>`_.

*   JR Golden, C Erickson-Davis, NP Cottaris, N Parthasarathy, F Rieke, DH Brainard, BA Wandell, EJ Chichilnisky (2018): Simulation of visual perception and learning with a retinal prosthesis. *bioRxiv 206409*, doi:`10.1101/206409 <https://doi.org/10.1101/206409>`_.